package KinoSearchX::Simple::Result::Hash;
use strict;
use warnings;

sub new{
    my ( $self, $data ) = @_;

    return $data;
}

1;
